@@ -4,8 +4,8 @@ pub const SEED_INDEX: &[u8] = b"idx";
 
 #[account]
 pub struct Index {
-    pub count: u128,
     pub owner: Pubkey,
     pub namespace: String,
+    pub item_count: u128,
     pub bump: u8,
 }
